==> jc-1.4.0.tar.gz: soot/jimple/parser/node/AReferenceVariable.h <==
// public final class soot.jimple.parser.node.AReferenceVariable

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 9087f72d257e170c soot_jimple_parser_node_AReferenceVariable
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class c929bf55a24d32c2 soot_jimple_parser_node_PVariable

// header file dependencies
// @dep_header soot_jimple_parser_node_PVariable

#include "soot/jimple/parser/node/PVariable.h"

#ifndef _JC_soot_jimple_parser_node_AReferenceVariable_H_
#define _JC_soot_jimple_parser_node_AReferenceVariable_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_PReference$object;
struct _jc_soot_jimple_parser_node_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AReferenceVariable$sub_refs	_jc_soot_jimple_parser_node_AReferenceVariable$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AReferenceVariable$sub_nonrefs	_jc_soot_jimple_parser_node_AReferenceVariable$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AReferenceVariable$refs	_jc_soot_jimple_parser_node_AReferenceVariable$refs;
typedef struct _jc_soot_jimple_parser_node_AReferenceVariable$nonrefs	_jc_soot_jimple_parser_node_AReferenceVariable$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AReferenceVariable$object	_jc_soot_jimple_parser_node_AReferenceVariable$object;

typedef const struct _jc_soot_jimple_parser_node_AReferenceVariable$vmethods	_jc_soot_jimple_parser_node_AReferenceVariable$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AReferenceVariable$vtable	_jc_soot_jimple_parser_node_AReferenceVariable$vtable;
typedef const struct _jc_soot_jimple_parser_node_AReferenceVariable$vtype	_jc_soot_jimple_parser_node_AReferenceVariable$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AReferenceVariable$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AReferenceVariable$object *);
extern void _jc_soot_jimple_parser_node_AReferenceVariable$method$_init$a6b928f349663da0(_jc_env *, struct _jc_soot_jimple_parser_node_AReferenceVariable$object *, struct _jc_soot_jimple_parser_node_PReference$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_AReferenceVariable$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AReferenceVariable$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AReferenceVariable$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AReferenceVariable$object *);
extern struct _jc_soot_jimple_parser_node_PReference$object *_jc_soot_jimple_parser_node_AReferenceVariable$method$getReference$731cb4a1297ac6a1(_jc_env *, struct _jc_soot_jimple_parser_node_AReferenceVariable$object *);
extern void _jc_soot_jimple_parser_node_AReferenceVariable$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AReferenceVariable$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AReferenceVariable$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AReferenceVariable$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AReferenceVariable$method$setReference$6a8a8e4fb98b5aa4(_jc_env *, struct _jc_soot_jimple_parser_node_AReferenceVariable$object *, struct _jc_soot_jimple_parser_node_PReference$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AReferenceVariable$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AReferenceVariable$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AReferenceVariable$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AReferenceVariable$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AReferenceVariable$method_info$getReference$731cb4a1297ac6a1;
extern _jc_method _jc_soot_jimple_parser_node_AReferenceVariable$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AReferenceVariable$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AReferenceVariable$method_info$setReference$6a8a8e4fb98b5aa4;
extern _jc_method _jc_soot_jimple_parser_node_AReferenceVariable$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AReferenceVariable$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AReferenceVariable$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AReferenceVariable$object *);
	struct _jc_soot_jimple_parser_node_PReference$object	*(*getReference$731cb4a1297ac6a1)(_jc_env *, struct _jc_soot_jimple_parser_node_AReferenceVariable$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AReferenceVariable$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AReferenceVariable$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setReference$6a8a8e4fb98b5aa4)(_jc_env *, struct _jc_soot_jimple_parser_node_AReferenceVariable$object *, struct _jc_soot_jimple_parser_node_PReference$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AReferenceVariable$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_AReferenceVariable$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PVariable$vmethods	soot_jimple_parser_node_PVariable;
	_jc_soot_jimple_parser_node_AReferenceVariable$vmethods	soot_jimple_parser_node_AReferenceVariable;
};

// Vtype
struct _jc_soot_jimple_parser_node_AReferenceVariable$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AReferenceVariable$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AReferenceVariable$sub_refs {
	struct _jc_soot_jimple_parser_node_PReference$object	*__5freference__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AReferenceVariable$refs {
    _jc_soot_jimple_parser_node_AReferenceVariable$sub_refs	soot_jimple_parser_node_AReferenceVariable;
    _jc_soot_jimple_parser_node_PVariable$sub_refs	soot_jimple_parser_node_PVariable;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AReferenceVariable$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AReferenceVariable$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PVariable$sub_nonrefs	soot_jimple_parser_node_PVariable;
    _jc_soot_jimple_parser_node_AReferenceVariable$sub_nonrefs	soot_jimple_parser_node_AReferenceVariable;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AReferenceVariable$object {
	_jc_soot_jimple_parser_node_AReferenceVariable$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AReferenceVariable$vtype	*vtype;
	_jc_soot_jimple_parser_node_AReferenceVariable$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AReferenceVariable$vtype _jc_soot_jimple_parser_node_AReferenceVariable$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AReferenceVariable, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AReferenceVariable$class_object;

#endif	/* _JC_soot_jimple_parser_node_AReferenceVariable_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/AReferenceVariable.h <==
// public final class soot.jimple.parser.node.AReferenceVariable

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 9087f72d257e170c soot_jimple_parser_node_AReferenceVariable
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class c929bf55a24d32c2 soot_jimple_parser_node_PVariable

// header file dependencies
// @dep_header soot_jimple_parser_node_PVariable

#include "soot/jimple/parser/node/PVariable.h"

#ifndef _JC_soot_jimple_parser_node_AReferenceVariable_H_
#define _JC_soot_jimple_parser_node_AReferenceVariable_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_PReference$object;
struct _jc_soot_jimple_parser_node_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AReferenceVariable$sub_refs	_jc_soot_jimple_parser_node_AReferenceVariable$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AReferenceVariable$sub_nonrefs	_jc_soot_jimple_parser_node_AReferenceVariable$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AReferenceVariable$refs	_jc_soot_jimple_parser_node_AReferenceVariable$refs;
typedef struct _jc_soot_jimple_parser_node_AReferenceVariable$nonrefs	_jc_soot_jimple_parser_node_AReferenceVariable$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AReferenceVariable$object	_jc_soot_jimple_parser_node_AReferenceVariable$object;

typedef const struct _jc_soot_jimple_parser_node_AReferenceVariable$vmethods	_jc_soot_jimple_parser_node_AReferenceVariable$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AReferenceVariable$vtable	_jc_soot_jimple_parser_node_AReferenceVariable$vtable;
typedef const struct _jc_soot_jimple_parser_node_AReferenceVariable$vtype	_jc_soot_jimple_parser_node_AReferenceVariable$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AReferenceVariable$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AReferenceVariable$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AReferenceVariable$method$_init$a6b928f349663da0(_jc_env *, struct _jc_soot_jimple_parser_node_AReferenceVariable$object *, struct _jc_soot_jimple_parser_node_PReference$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_AReferenceVariable$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AReferenceVariable$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AReferenceVariable$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AReferenceVariable$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_PReference$object *_jc_soot_jimple_parser_node_AReferenceVariable$method$getReference$731cb4a1297ac6a1(_jc_env *, struct _jc_soot_jimple_parser_node_AReferenceVariable$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AReferenceVariable$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AReferenceVariable$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AReferenceVariable$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AReferenceVariable$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AReferenceVariable$method$setReference$6a8a8e4fb98b5aa4(_jc_env *, struct _jc_soot_jimple_parser_node_AReferenceVariable$object *, struct _jc_soot_jimple_parser_node_PReference$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AReferenceVariable$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AReferenceVariable$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AReferenceVariable$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AReferenceVariable$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AReferenceVariable$method_info$getReference$731cb4a1297ac6a1;
extern _jc_method _jc_soot_jimple_parser_node_AReferenceVariable$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AReferenceVariable$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AReferenceVariable$method_info$setReference$6a8a8e4fb98b5aa4;
extern _jc_method _jc_soot_jimple_parser_node_AReferenceVariable$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AReferenceVariable$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AReferenceVariable$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AReferenceVariable$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_PReference$object	*(*getReference$731cb4a1297ac6a1)(_jc_env *, struct _jc_soot_jimple_parser_node_AReferenceVariable$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AReferenceVariable$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AReferenceVariable$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setReference$6a8a8e4fb98b5aa4)(_jc_env *, struct _jc_soot_jimple_parser_node_AReferenceVariable$object *, struct _jc_soot_jimple_parser_node_PReference$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AReferenceVariable$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_AReferenceVariable$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PVariable$vmethods	soot_jimple_parser_node_PVariable;
	_jc_soot_jimple_parser_node_AReferenceVariable$vmethods	soot_jimple_parser_node_AReferenceVariable;
};

// Vtype
struct _jc_soot_jimple_parser_node_AReferenceVariable$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AReferenceVariable$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AReferenceVariable$sub_refs {
	struct _jc_soot_jimple_parser_node_PReference$object	*__5freference__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AReferenceVariable$refs {
    _jc_soot_jimple_parser_node_AReferenceVariable$sub_refs	soot_jimple_parser_node_AReferenceVariable;
    _jc_soot_jimple_parser_node_PVariable$sub_refs	soot_jimple_parser_node_PVariable;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AReferenceVariable$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AReferenceVariable$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PVariable$sub_nonrefs	soot_jimple_parser_node_PVariable;
    _jc_soot_jimple_parser_node_AReferenceVariable$sub_nonrefs	soot_jimple_parser_node_AReferenceVariable;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AReferenceVariable$object {
	_jc_soot_jimple_parser_node_AReferenceVariable$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AReferenceVariable$vtype	*vtype;
	_jc_soot_jimple_parser_node_AReferenceVariable$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AReferenceVariable$vtype _jc_soot_jimple_parser_node_AReferenceVariable$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AReferenceVariable, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AReferenceVariable$class_object;

#endif	/* _JC_soot_jimple_parser_node_AReferenceVariable_H_ */
